"""
pypxl - an asyncronous wrapper for pxlapi (pxlapi.dev)

:copyright: (c) 2021 Kile
:license: MIT, see LICENSE for more details
"""

__title__ = "pypxl"
__author__ = "Kile"
__license__ = "MIT"
__copyright__ = "Copyright 2021 Kile"
__version__ = "0.1.1"

from .client import Pxlapi


class PxlapiException(Exception):
    pass

class InvalidFlag(PxlapiException):
    pass

class InvalidFilter(PxlapiException):
    pass

class TooManyCharacters(PxlapiException):
    pass

class InvalidSafety(PxlapiException):
    pass